Modules › DataTables — Stisla

# DataTables

We use 'DataTables' made by @SpryMedia. You can check the full documentation here.

#### Basic DataTables

# | Task Name | Progress | Members | Due Date | Status | Action
--- | --- | --- | --- | --- | --- | ---
1 | Create a mobile app |  |  | 2018-01-20 | Completed | Detail
2 | Redesign homepage |  |  | 2018-04-10 | Todo | Detail
3 | Backup database |  |  | 2018-01-29 | In Progress | Detail
4 | Input data |  |  | 2018-01-16 | Completed | Detail

#### Advanced Table

| Task Name | Progress | Members | Due Date | Status | Action
--- | --- | --- | --- | --- | --- | ---
| Create a mobile app |  |  | 2018-01-20 | Completed | Detail
| Redesign homepage |  |  | 2018-04-10 | Todo | Detail
| Backup database |  |  | 2018-01-29 | In Progress | Detail
| Input data |  |  | 2018-01-16 | Completed | Detail